package Locale::CLDR::Locales::Cy::Any;

# This file auto generated
#	on Sun 25 Oct  8:39:48 am GMT

use version;

our $VERSION = version->declare('v0.28.1');

use v5.10.1;
use mro 'c3';
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Moose;

extends('Locale::CLDR::Locales::Cy');

no Moose;
__PACKAGE__->meta->make_immutable;
